Package 'pedsuite'

Title: Easy Installation of the 'pedsuite' Packages for Pedigree Analysis
Description: The 'pedsuite' is a collection of packages for pedigree analysis, covering applications in forensic genetics, medical genetics and more. A detailed presentation of the 'pedsuite' is given in the book 'Pedigree Analysis in R' (Vigeland, 2021, ISBN: 9780128244302).
Authors: Magnus Dehli Vigeland [aut, cre] (ORCID: <https://orcid.org/0000-0002-9134-4962>), Thore Egeland [aut] (ORCID: <https://orcid.org/0000-0002-3465-8885>)
Maintainer: Magnus Dehli Vigeland <[email protected]>
License: GPL (>= 3)
Version: 1.4.0
Built: 2026-05-26 17:59:14 UTC
Source: https://github.com/magnusdv/pedsuite

Help Index